summaryrefslogtreecommitdiffstats
path: root/lib
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:51:21 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-15 15:51:21 -0600
commitb6ba5d642f3fc7d320e3d6f4650eb259a3a52b04 (patch)
tree76f49820693d443128d3720322ff1605e9bcd558 /lib
parent247f828db1b8dcdc9346c1568d81cfa00db99c9e (diff)
downloadtdevelop-b6ba5d642f3fc7d320e3d6f4650eb259a3a52b04.tar.gz
tdevelop-b6ba5d642f3fc7d320e3d6f4650eb259a3a52b04.zip
Rename a number of old tq methods that are no longer tq specific
Diffstat (limited to 'lib')
-rw-r--r--lib/antlr/antlr/AST.hpp4
-rw-r--r--lib/antlr/antlr/ASTFactory.hpp2
-rw-r--r--lib/antlr/antlr/BaseAST.hpp4
-rw-r--r--lib/antlr/src/ASTFactory.cpp10
-rw-r--r--lib/antlr/src/BaseAST.cpp12
-rw-r--r--lib/catalog/tag.h2
-rw-r--r--lib/cppparser/ast.cpp8
-rw-r--r--lib/cppparser/ast.h4
-rw-r--r--lib/cppparser/driver.cpp2
-rw-r--r--lib/cppparser/lexer.cpp12
-rw-r--r--lib/cppparser/lexer.h4
-rw-r--r--lib/cppparser/lexercache.cpp6
-rw-r--r--lib/cppparser/lexercache.h2
-rw-r--r--lib/cppparser/parser.cpp6
-rw-r--r--lib/interfaces/extensions/kdevcreatefile.h4
-rw-r--r--lib/interfaces/extensions/kdevversioncontrol.h8
-rw-r--r--lib/interfaces/external/designer.h2
-rw-r--r--lib/interfaces/hashedstring.cpp6
-rw-r--r--lib/interfaces/kdevplugincontroller.cpp2
-rw-r--r--lib/interfaces/kdevplugininfo.cpp4
-rw-r--r--lib/util/blockingkprocess.cpp4
-rw-r--r--lib/util/domutil.cpp16
-rw-r--r--lib/util/domutil.h2
-rw-r--r--lib/util/execcommand.cpp4
-rw-r--r--lib/util/filetemplate.cpp6
-rw-r--r--lib/util/kscriptactionmanager.cpp2
-rw-r--r--lib/util/settings.cpp6
-rw-r--r--lib/util/urlutil.cpp2
-rw-r--r--lib/widgets/fancylistviewitem.cpp6
-rw-r--r--lib/widgets/flagboxes.cpp20
-rw-r--r--lib/widgets/kdevhtmlpart.cpp4
-rw-r--r--lib/widgets/processwidget.cpp10
-rw-r--r--lib/widgets/processwidget.h2
-rw-r--r--lib/widgets/propeditor/pcheckbox.cpp4
-rw-r--r--lib/widgets/propeditor/pcolorbutton.cpp4
-rw-r--r--lib/widgets/propeditor/pcolorcombo.cpp4
-rw-r--r--lib/widgets/propeditor/pcombobox.cpp4
-rw-r--r--lib/widgets/propeditor/pdateedit.cpp4
-rw-r--r--lib/widgets/propeditor/pdatetimeedit.cpp4
-rw-r--r--lib/widgets/propeditor/pdoublenuminput.cpp6
-rw-r--r--lib/widgets/propeditor/pfontbutton.cpp6
-rw-r--r--lib/widgets/propeditor/pfontcombo.cpp4
-rw-r--r--lib/widgets/propeditor/plineedit.cpp4
-rw-r--r--lib/widgets/propeditor/plinestyleedit.cpp4
-rw-r--r--lib/widgets/propeditor/ppixmapedit.cpp6
-rw-r--r--lib/widgets/propeditor/ppointedit.cpp8
-rw-r--r--lib/widgets/propeditor/prectedit.cpp8
-rw-r--r--lib/widgets/propeditor/property.h2
-rw-r--r--lib/widgets/propeditor/propertyeditor.cpp16
-rw-r--r--lib/widgets/propeditor/propertywidgetproxy.cpp2
-rw-r--r--lib/widgets/propeditor/psizeedit.cpp8
-rw-r--r--lib/widgets/propeditor/psizepolicyedit.cpp8
-rw-r--r--lib/widgets/propeditor/pspinbox.cpp4
-rw-r--r--lib/widgets/propeditor/pstringlistedit.cpp6
-rw-r--r--lib/widgets/propeditor/psymbolcombo.cpp10
-rw-r--r--lib/widgets/propeditor/purledit.cpp4
-rw-r--r--lib/widgets/propeditor/pyesnobutton.cpp4
-rw-r--r--lib/widgets/propeditor/qeditlistbox.cpp4
-rw-r--r--lib/widgets/propeditor/qfloatinput.cpp2
-rw-r--r--lib/widgets/qcomboview.cpp62
-rw-r--r--lib/widgets/qcomboview.h2
-rw-r--r--lib/widgets/resizablecombo.cpp2
62 files changed, 197 insertions, 197 deletions
diff --git a/lib/antlr/antlr/AST.hpp b/lib/antlr/antlr/AST.hpp
index b14b123b..b01a60a9 100644
--- a/lib/antlr/antlr/AST.hpp
+++ b/lib/antlr/antlr/AST.hpp
@@ -63,10 +63,10 @@ public:
/// Add a node to the end of the child list for this node
virtual void addChild(RefAST c) = 0;
- /// Get the number of tqchildren. Returns 0 if the node is a leaf
+ /// Get the number of children. Returns 0 if the node is a leaf
virtual size_t getNumberOfChildren() const = 0;
- /// Get the first child of this node; null if no tqchildren
+ /// Get the first child of this node; null if no children
virtual RefAST getFirstChild() const = 0;
/// Get the next sibling in line after this one
virtual RefAST getNextSibling() const = 0;
diff --git a/lib/antlr/antlr/ASTFactory.hpp b/lib/antlr/antlr/ASTFactory.hpp
index 0fb78dc1..968ab6c5 100644
--- a/lib/antlr/antlr/ASTFactory.hpp
+++ b/lib/antlr/antlr/ASTFactory.hpp
@@ -86,7 +86,7 @@ public:
RefAST dupTree(RefAST t);
/** Make a tree from a list of nodes. The first element in the
* array is the root. If the root is null, then the tree is
- * a simple list not a tree. Handles null tqchildren nodes correctly.
+ * a simple list not a tree. Handles null children nodes correctly.
* For example, make(a, b, null, c) yields tree (a b c). make(null,a,b)
* yields tree (nil a b).
*/
diff --git a/lib/antlr/antlr/BaseAST.hpp b/lib/antlr/antlr/BaseAST.hpp
index 3a88db32..1bfc4e56 100644
--- a/lib/antlr/antlr/BaseAST.hpp
+++ b/lib/antlr/antlr/BaseAST.hpp
@@ -96,7 +96,7 @@ public:
*/
virtual size_t getNumberOfChildren() const;
- /// Get the first child of this node; null if no tqchildren
+ /// Get the first child of this node; null if no children
virtual RefAST getFirstChild() const
{
return RefAST(down);
@@ -118,7 +118,7 @@ public:
return 0;
}
- /// Remove all tqchildren
+ /// Remove all children
virtual void removeChildren()
{
down = static_cast<BaseAST*>(static_cast<AST*>(nullAST));
diff --git a/lib/antlr/src/ASTFactory.cpp b/lib/antlr/src/ASTFactory.cpp
index a255ca10..98ce6b7a 100644
--- a/lib/antlr/src/ASTFactory.cpp
+++ b/lib/antlr/src/ASTFactory.cpp
@@ -217,7 +217,7 @@ RefAST ASTFactory::dupList(RefAST t)
RefAST ASTFactory::dupTree(RefAST t)
{
RefAST result = dup(t); // make copy of root
- // copy all tqchildren of root.
+ // copy all children of root.
if( t )
result->setFirstChild( dupList(t->getFirstChild()) );
return result;
@@ -225,7 +225,7 @@ RefAST ASTFactory::dupTree(RefAST t)
/** Make a tree from a list of nodes. The first element in the
* array is the root. If the root is null, then the tree is
- * a simple list not a tree. Handles null tqchildren nodes correctly.
+ * a simple list not a tree. Handles null children nodes correctly.
* For example, make(a, b, null, c) yields tree (a b c). make(null,a,b)
* yields tree (nil a b).
*/
@@ -240,7 +240,7 @@ RefAST ASTFactory::make(ANTLR_USE_NAMESPACE(std)vector<RefAST>& nodes)
if( root )
root->setFirstChild(RefAST(nullASTptr)); // don't leave any old pointers set
- // link in tqchildren;
+ // link in children;
for( unsigned int i = 1; i < nodes.size(); i++ )
{
if ( nodes[i] == 0 ) // ignore null nodes
@@ -336,7 +336,7 @@ void ASTFactory::loadChildren( ANTLR_USE_NAMESPACE(std)istream& infile,
{
char ch;
- for(;;) // for all tqchildren of this node....
+ for(;;) // for all children of this node....
{
eatwhite(infile);
@@ -438,7 +438,7 @@ RefAST ASTFactory::LoadAST( ANTLR_USE_NAMESPACE(std)istream& infile )
infile.get(ch);
// now if we have a '/' here it's a single node. If it's a '>' we get
- // a tree with tqchildren
+ // a tree with children
if( ch == '/' )
{
diff --git a/lib/antlr/src/BaseAST.cpp b/lib/antlr/src/BaseAST.cpp
index 17d8de68..f10f1e16 100644
--- a/lib/antlr/src/BaseAST.cpp
+++ b/lib/antlr/src/BaseAST.cpp
@@ -47,7 +47,7 @@ void BaseAST::doWorkForFindAll(
(!partialMatch && sibling->equalsTree(target)) ) {
v.push_back(sibling);
}
- // regardless of match or not, check any tqchildren for matches
+ // regardless of match or not, check any children for matches
if ( sibling->getFirstChild() ) {
RefBaseAST(sibling->getFirstChild())->doWorkForFindAll(v, target, partialMatch);
}
@@ -70,7 +70,7 @@ bool BaseAST::equalsList(RefAST t) const
// as a quick optimization, check roots first.
if (!sibling->equals(t))
return false;
- // if roots match, do full list match test on tqchildren.
+ // if roots match, do full list match test on children.
if (sibling->getFirstChild()) {
if (!sibling->getFirstChild()->equalsList(t->getFirstChild()))
return false;
@@ -103,7 +103,7 @@ bool BaseAST::equalsListPartial(RefAST sub) const
// as a quick optimization, check roots first.
if (!sibling->equals(sub))
return false;
- // if roots match, do partial list match test on tqchildren.
+ // if roots match, do partial list match test on children.
if (sibling->getFirstChild())
if (!sibling->getFirstChild()->equalsListPartial(sub->getFirstChild()))
return false;
@@ -125,7 +125,7 @@ bool BaseAST::equalsTree(RefAST t) const
// check roots first
if (!equals(t))
return false;
- // if roots match, do full list match test on tqchildren.
+ // if roots match, do full list match test on children.
if (getFirstChild()) {
if (!getFirstChild()->equalsList(t->getFirstChild()))
return false;
@@ -149,7 +149,7 @@ bool BaseAST::equalsTreePartial(RefAST sub) const
// check roots first
if (!equals(sub))
return false;
- // if roots match, do full list partial match test on tqchildren.
+ // if roots match, do full list partial match test on children.
if (getFirstChild())
if (!getFirstChild()->equalsListPartial(sub->getFirstChild()))
return false;
@@ -256,7 +256,7 @@ void BaseAST::toStream( ANTLR_USE_NAMESPACE(std)ostream& out ) const
if( need_close_tag )
{
- // got tqchildren so write them...
+ // got children so write them...
if( node->getFirstChild() != 0 )
node->getFirstChild()->toStream( out );
diff --git a/lib/catalog/tag.h b/lib/catalog/tag.h
index 95604c83..a3f7711b 100644
--- a/lib/catalog/tag.h
+++ b/lib/catalog/tag.h
@@ -122,7 +122,7 @@ public:
data->fileName = fileName;
}
- TQString path( const TQString& sep = TQString::tqfromLatin1("::") ) const
+ TQString path( const TQString& sep = TQString::fromLatin1("::") ) const
{
TQString s = scope().join( sep );
if( s.isNull() )
diff --git a/lib/cppparser/ast.cpp b/lib/cppparser/ast.cpp
index e4e3cf5d..8f2f2ad7 100644
--- a/lib/cppparser/ast.cpp
+++ b/lib/cppparser/ast.cpp
@@ -136,7 +136,7 @@ AST::AST()
m_endLine( 0 ), m_endColumn( 0 )
{
#ifndef CPPPARSER_NO_CHILDREN
- m_tqchildren.setAutoDelete( false );
+ m_children.setAutoDelete( false );
#endif
}
@@ -196,12 +196,12 @@ void AST::setParent( AST* parent )
#ifndef CPPPARSER_NO_CHILDREN
void AST::appendChild( AST* child )
{
- m_tqchildren.append( child );
+ m_children.append( child );
}
void AST::removeChild( AST* child )
{
- m_tqchildren.remove( child );
+ m_children.remove( child );
}
#endif
@@ -474,7 +474,7 @@ TQString ClassOrNamespaceNameAST::text() const
TQString str = m_name->text();
if( m_templateArgumentList.get() )
- str += TQString::tqfromLatin1("< ") + m_templateArgumentList->text() + TQString::tqfromLatin1(" >");
+ str += TQString::fromLatin1("< ") + m_templateArgumentList->text() + TQString::fromLatin1(" >");
return str;
}
diff --git a/lib/cppparser/ast.h b/lib/cppparser/ast.h
index c98c2fe7..5db231fd 100644
--- a/lib/cppparser/ast.h
+++ b/lib/cppparser/ast.h
@@ -263,7 +263,7 @@ public:
void getEndPosition( int* line, int* col ) const;
#ifndef CPPPARSER_NO_CHILDREN
- TQPtrList<AST> tqchildren() { return m_tqchildren; }
+ TQPtrList<AST> children() { return m_children; }
void appendChild( AST* child );
void removeChild( AST* child );
#endif
@@ -292,7 +292,7 @@ private:
int m_endLine, m_endColumn;
Slice m_slice;
#ifndef CPPPARSER_NO_CHILDREN
- TQPtrList<AST> m_tqchildren;
+ TQPtrList<AST> m_children;
#endif
private:
diff --git a/lib/cppparser/driver.cpp b/lib/cppparser/driver.cpp
index bcaea218..91945e53 100644
--- a/lib/cppparser/driver.cpp
+++ b/lib/cppparser/driver.cpp
@@ -383,7 +383,7 @@ void Driver::addDependence( const TQString & fileName, const Dependence & dep )
m_currentParsedFile->addIncludeFile( file, 0, dep.second == Dep_Local );
if ( !TQFile::exists( file ) ) {
- Problem p( i18n( "Could not find include file %1" ).tqarg( dep.first ),
+ Problem p( i18n( "Could not find include file %1" ).arg( dep.first ),
lexer ? lexer->currentLine() : -1,
lexer ? lexer->currentColumn() : -1, Problem::Level_Warning );
addProblem( fileName, p );
diff --git a/lib/cppparser/lexer.cpp b/lib/cppparser/lexer.cpp
index 1ed9fca7..167c88c4 100644
--- a/lib/cppparser/lexer.cpp
+++ b/lib/cppparser/lexer.cpp
@@ -184,7 +184,7 @@ int Lexer::toInt( const Token& token )
int i = s[0] == 'L' ? 2 : 1; // wide char ?
if( s[i] == '\\' ){
// escaped char
- int c = s[i+1].tqunicode();
+ int c = s[i+1].unicode();
switch( c ) {
case '0':
return 0;
@@ -195,7 +195,7 @@ int Lexer::toInt( const Token& token )
return c;
}
} else {
- return s[i].tqunicode();
+ return s[i].unicode();
}
} else {
return 0;
@@ -386,21 +386,21 @@ void Lexer::nextToken( Token& tk, bool stopOnNewline )
TQString tokText = tok.text();
HashedString str = (tok == Token_identifier && d->hasBind(tokText)) ? d->apply( tokText ) : tokText;
if( str == ide ){
- //Problem p( i18n("unsafe use of macro '%1', macro is ignored").tqarg(ide.str()), m_currentLine, m_currentColumn, Problem::Level_Warning );
+ //Problem p( i18n("unsafe use of macro '%1', macro is ignored").arg(ide.str()), m_currentLine, m_currentColumn, Problem::Level_Warning );
//m_driver->addProblem( m_driver->currentFileName(), p );
m_driver->removeMacro( ide );
// str = TQString();
}
if( stringify ) {
- textToInsert.append( TQString::tqfromLatin1("\"") + str.str() + TQString::tqfromLatin1("\" ") );
+ textToInsert.append( TQString::fromLatin1("\"") + str.str() + TQString::fromLatin1("\" ") );
} else if( merge ){
textToInsert.truncate( textToInsert.length() - 1 );
- textToInsert.append( str.str() + TQString::tqfromLatin1(" ") );
+ textToInsert.append( str.str() + TQString::fromLatin1(" ") );
} else if( tok == Token_ellipsis && d->hasBind("...") ){
textToInsert.append( ellipsisArg );
} else {
- textToInsert.append( str.str() + TQString::tqfromLatin1(" ") );
+ textToInsert.append( str.str() + TQString::fromLatin1(" ") );
}
}
diff --git a/lib/cppparser/lexer.h b/lib/cppparser/lexer.h
index 2630edf7..12f16696 100644
--- a/lib/cppparser/lexer.h
+++ b/lib/cppparser/lexer.h
@@ -244,11 +244,11 @@ public:
int currentColumn() const { return m_currentColumn; }
inline const CHARTYPE* offset( int offset ) const {
- return m_source.tqunicode() + offset;
+ return m_source.unicode() + offset;
}
inline int getOffset( const TQChar* p ) const {
- return int(p - (m_source.tqunicode()));
+ return int(p - (m_source.unicode()));
}
private:
diff --git a/lib/cppparser/lexercache.cpp b/lib/cppparser/lexercache.cpp
index 7f420cac..cbe8640d 100644
--- a/lib/cppparser/lexercache.cpp
+++ b/lib/cppparser/lexercache.cpp
@@ -112,13 +112,13 @@ TQDateTime LexerCache::fileModificationTimeCached( const HashedString& fileName
FileModificationMap::const_iterator it = m_fileModificationCache.find( fileName );
if( it != m_fileModificationCache.end() ) {
///Use the cache for 10 seconds
- if( (*it).second.m_readTime.secsTo( m_tqcurrentDateTime ) < 10 ) {
+ if( (*it).second.m_readTime.secsTo( m_currentDateTime ) < 10 ) {
return (*it).second.m_modificationTime;
}
}
TQFileInfo fileInfo( fileName.str() );
- m_fileModificationCache[fileName].m_readTime = TQDateTime::tqcurrentDateTime();
+ m_fileModificationCache[fileName].m_readTime = TQDateTime::currentDateTime();
m_fileModificationCache[fileName].m_modificationTime = fileInfo.lastModified();
return fileInfo.lastModified();
@@ -239,7 +239,7 @@ size_t CachedLexedFile::hash() const {
}
void LexerCache::initFileModificationCache() {
- m_tqcurrentDateTime = TQDateTime::tqcurrentDateTime();
+ m_currentDateTime = TQDateTime::currentDateTime();
}
void LexerCache::saveMemory() {
diff --git a/lib/cppparser/lexercache.h b/lib/cppparser/lexercache.h
index 535768bc..c1aac432 100644
--- a/lib/cppparser/lexercache.h
+++ b/lib/cppparser/lexercache.h
@@ -155,7 +155,7 @@ class LexerCache : public CacheManager {
typedef __gnu_cxx::hash_map<HashedString, FileModificationCache> FileModificationMap;
FileModificationMap m_fileModificationCache;
Driver* m_driver;
- TQDateTime m_tqcurrentDateTime;
+ TQDateTime m_currentDateTime;
};
diff --git a/lib/cppparser/parser.cpp b/lib/cppparser/parser.cpp
index 9b0a0c1f..08b4e6bb 100644
--- a/lib/cppparser/parser.cpp
+++ b/lib/cppparser/parser.cpp
@@ -37,7 +37,7 @@ using namespace std;
{ \
const Token& token = lex->lookAhead( 0 ); \
if( token != tk ){ \
- reportError( i18n("'%1' expected found '%2'").tqarg(descr).tqarg(token.text()) ); \
+ reportError( i18n("'%1' expected found '%2'").arg(descr).arg(token.text()) ); \
return false; \
} \
nextToken(); \
@@ -47,7 +47,7 @@ using namespace std;
{ \
const Token& token = lex->lookAhead( 0 ); \
if( token != tk ){ \
- reportError( i18n("'%1' expected found '%2'").tqarg(descr).tqarg(token.text()) ); \
+ reportError( i18n("'%1' expected found '%2'").arg(descr).arg(token.text()) ); \
} \
else \
nextToken(); \
@@ -139,7 +139,7 @@ bool Parser::reportError( const Error& err )
if( s.isEmpty() )
s = i18n( "<eof>" );
- m_driver->addProblem( m_driver->currentFileName(), Problem(err.text.tqarg(s), line, col) );
+ m_driver->addProblem( m_driver->currentFileName(), Problem(err.text.arg(s), line, col) );
}
return true;
diff --git a/lib/interfaces/extensions/kdevcreatefile.h b/lib/interfaces/extensions/kdevcreatefile.h
index ee30f555..76dff18b 100644
--- a/lib/interfaces/extensions/kdevcreatefile.h
+++ b/lib/interfaces/extensions/kdevcreatefile.h
@@ -54,7 +54,7 @@ public:
public:
/**The status of a file.*/
- enum tqStatus {
+ enum Status {
STATUS_OK /**<File was successfuly created.*/,
STATUS_CANCELED /**<File was not created due to user intervention.*/,
STATUS_NOTCREATED /**<File was not created due to error.*/,
@@ -105,7 +105,7 @@ public:
there are several file templates for each extension.*/
TQString subtype;
/**Current status.*/
- tqStatus status;
+ Status status;
/**true if the file should be added to a project.*/
bool addToProject;
};
diff --git a/lib/interfaces/extensions/kdevversioncontrol.h b/lib/interfaces/extensions/kdevversioncontrol.h
index 2dcfe869..2b61805d 100644
--- a/lib/interfaces/extensions/kdevversioncontrol.h
+++ b/lib/interfaces/extensions/kdevversioncontrol.h
@@ -198,7 +198,7 @@ public:
This is a <b>synchronous operation</b> (blocking).
@param dirPath The relative (to project dir) directory path to stat.
- @return tqStatus for all <b>registered</b> files.*/
+ @return Status for all <b>registered</b> files.*/
virtual const VCSFileInfoMap *status(const TQString &dirPath) = 0;
/**Starts a request for directory status to the remote repository.
@@ -210,18 +210,18 @@ public:
@param dirPath The (relative to project directory) directory which status you are asking for.
@param callerData The pointer to some data you want the provider will return
to you when it has done.
- @param recursive If false, retrieve information only for dirPath's immediate tqchildren.
+ @param recursive If false, retrieve information only for dirPath's immediate children.
@param checkRepos If true, contact remote repository and augment repository's status.
If false, retrieve only for local modification information.
@return true if the request has been successfully started, false otherwise.*/
- virtual bool requesttqStatus( const TQString &dirPath, void *callerData, bool recursive = true, bool checkRepos = true ) = 0;
+ virtual bool requestStatus( const TQString &dirPath, void *callerData, bool recursive = true, bool checkRepos = true ) = 0;
signals:
/**Emitted when the status request to remote repository has finished.
@param fileInfoMap The status for <b>registered in repository</b> files.
@param callerData The pointer to some data you want the provider will return
to you when it has done
- @see requesttqStatus for to find out when this signal should be used.*/
+ @see requestStatus for to find out when this signal should be used.*/
void statusReady(const VCSFileInfoMap &fileInfoMap, void *callerData);
protected:
diff --git a/lib/interfaces/external/designer.h b/lib/interfaces/external/designer.h
index 9f0c0064..c071f2db 100644
--- a/lib/interfaces/external/designer.h
+++ b/lib/interfaces/external/designer.h
@@ -91,7 +91,7 @@ signals:
/**Emitted when a form state is changed in the designer.
@param formName An absolute name of the form file.
@param status 0: form is clean, 1: form is modified.*/
- void newtqStatus(const TQString &formName, int status);
+ void newStatus(const TQString &formName, int status);
};
}
diff --git a/lib/interfaces/hashedstring.cpp b/lib/interfaces/hashedstring.cpp
index f974df10..8392e271 100644
--- a/lib/interfaces/hashedstring.cpp
+++ b/lib/interfaces/hashedstring.cpp
@@ -30,7 +30,7 @@ size_t hashStringSafe( const TQString& str ) {
size_t hash = 0;
int len = str.length();
for( int a = 0; a < len; a++ ) {
- hash = str[a].tqunicode() + (hash * 17);
+ hash = str[a].unicode() + (hash * 17);
}
return hash;
}
@@ -43,12 +43,12 @@ size_t HashedString::hashString( const TQString& str )
size_t fastHashString( const TQString& str ) {
size_t hash = 0;
if( !str.isEmpty() ) {
- const TQChar* curr = str.tqunicode();
+ const TQChar* curr = str.unicode();
const TQChar* end = curr + str.length();
TQChar c;
for(; curr < end ;) {
c = *curr;
- hash = c.tqunicode() + ( hash * 17 );
+ hash = c.unicode() + ( hash * 17 );
++curr;
}
}
diff --git a/lib/interfaces/kdevplugincontroller.cpp b/lib/interfaces/kdevplugincontroller.cpp
index 86384440..c9746047 100644
--- a/lib/interfaces/kdevplugincontroller.cpp
+++ b/lib/interfaces/kdevplugincontroller.cpp
@@ -28,7 +28,7 @@ KTrader::OfferList KDevPluginController::query(const TQString &serviceType,
const TQString &constraint)
{
return KTrader::self()->query(serviceType,
- TQString("%1 and [X-KDevelop-Version] == %2").tqarg(constraint).tqarg(KDEVELOP_PLUGIN_VERSION));
+ TQString("%1 and [X-KDevelop-Version] == %2").arg(constraint).arg(KDEVELOP_PLUGIN_VERSION));
}
KTrader::OfferList KDevPluginController::queryPlugins(const TQString &constraint)
diff --git a/lib/interfaces/kdevplugininfo.cpp b/lib/interfaces/kdevplugininfo.cpp
index ae5ddf2d..6c869d23 100644
--- a/lib/interfaces/kdevplugininfo.cpp
+++ b/lib/interfaces/kdevplugininfo.cpp
@@ -149,7 +149,7 @@ TQString KDevPluginInfo::bugsEmailAddress() const
TQVariant KDevPluginInfo::property(const TQString &name) const
{
- KTrader::OfferList offers = KDevPluginController::queryPlugins(TQString("Name='%1'").tqarg(d->m_pluginName));
+ KTrader::OfferList offers = KDevPluginController::queryPlugins(TQString("Name='%1'").arg(d->m_pluginName));
if (offers.count() == 1)
return offers.first()->property(name);
return TQVariant();
@@ -162,7 +162,7 @@ TQVariant KDevPluginInfo::operator [](const TQString &name) const
TQStringList KDevPluginInfo::propertyNames( ) const
{
- KTrader::OfferList offers = KDevPluginController::queryPlugins(TQString("Name='%1'").tqarg(d->m_pluginName));
+ KTrader::OfferList offers = KDevPluginController::queryPlugins(TQString("Name='%1'").arg(d->m_pluginName));
if (offers.count() == 1)
return offers.first()->propertyNames();
return TQStringList();
diff --git a/lib/util/blockingkprocess.cpp b/lib/util/blockingkprocess.cpp
index 51845a5c..c0d1b106 100644
--- a/lib/util/blockingkprocess.cpp
+++ b/lib/util/blockingkprocess.cpp
@@ -68,12 +68,12 @@ bool BlockingKProcess::start(RunMode runmode, Communication comm)
void BlockingKProcess::slotReceivedStdOut(KProcess *, char *buffer, int buflen)
{
- m_stdOut += TQString::tqfromLatin1(buffer, buflen);
+ m_stdOut += TQString::fromLatin1(buffer, buflen);
}
void BlockingKProcess::slotReceivedStdErr(KProcess *, char *buffer, int buflen)
{
- m_stdErr += TQString::tqfromLatin1(buffer, buflen);
+ m_stdErr += TQString::fromLatin1(buffer, buflen);
}
void BlockingKProcess::slotProcessExited(KProcess *)
diff --git a/lib/util/domutil.cpp b/lib/util/domutil.cpp
index 0c9a2491..1f148fad 100644
--- a/lib/util/domutil.cpp
+++ b/lib/util/domutil.cpp
@@ -260,18 +260,18 @@ TQDomElement DomUtil::elementByPathExt(TQDomDocument &doc, const TQString &paths
{
DomPath dompath = resolvPathStringExt(pathstring);
TQDomElement elem = doc.documentElement();
- TQDomNodeList tqchildren;
+ TQDomNodeList children;
TQDomElement nextElem = elem;
for (unsigned int j=0; j<dompath.count(); j++)
{
- tqchildren = nextElem.childNodes();
+ children = nextElem.childNodes();
DomPathElement dompathelement= dompath[j];
bool wrongchild = false;
int matchCount = 0;
- for (unsigned int i=0; i<tqchildren.count(); i++)
+ for (unsigned int i=0; i<children.count(); i++)
{
wrongchild = false;
- TQDomElement child = tqchildren.item(i).toElement();
+ TQDomElement child = children.item(i).toElement();
TQString tag = child.tagName();
tag = dompathelement.tagName;
if (child.tagName() == dompathelement.tagName)
@@ -339,10 +339,10 @@ bool DomUtil::removeTextNodes(TQDomDocument doc,TQString pathExt)
TQDomElement elem = elementByPathExt(doc,pathExt);
if (elem.isNull())
return false;
- TQDomNodeList tqchildren = elem.childNodes();
- for (unsigned int i=0;i<tqchildren.count();i++)
- if (tqchildren.item(i).isText())
- elem.removeChild(tqchildren.item(i));
+ TQDomNodeList children = elem.childNodes();
+ for (unsigned int i=0;i<children.count();i++)
+ if (children.item(i).isText())
+ elem.removeChild(children.item(i));
return true;
}
diff --git a/lib/util/domutil.h b/lib/util/domutil.h
index ea28a407..7856e3c6 100644
--- a/lib/util/domutil.h
+++ b/lib/util/domutil.h
@@ -168,7 +168,7 @@ public:
Retrieve an element specified with extended path
examples:
- - 1: "widget|class=TQDialog/property|name=tqgeometry"
+ - 1: "widget|class=TQDialog/property|name=geometry"
or "widget|class=TQDialog/property||1"
- 2: "widget/property|name=caption/string"
or "widget/property||2/string"
diff --git a/lib/util/execcommand.cpp b/lib/util/execcommand.cpp
index b3d83746..62eb5924 100644
--- a/lib/util/execcommand.cpp
+++ b/lib/util/execcommand.cpp
@@ -49,7 +49,7 @@ ExecCommand::ExecCommand( const TQString& executable, const TQStringList& args,
bool ok = proc->start( KProcess::NotifyOnExit, KProcess::AllOutput );
if ( !ok ) {
- KMessageBox::error( 0, i18n("Could not invoke \"%1\". Please make sure it is installed correctly").tqarg( executable ),
+ KMessageBox::error( 0, i18n("Could not invoke \"%1\". Please make sure it is installed correctly").arg( executable ),
i18n("Error Invoking Command") );
emit finished( TQString(), TQString() );
@@ -57,7 +57,7 @@ ExecCommand::ExecCommand( const TQString& executable, const TQStringList& args,
} else {
progressDlg = new KProgressDialog( 0, 0, i18n("Command running..."),
- i18n("Please wait until the \"%1\" command finishes.").tqarg( executable ), false );
+ i18n("Please wait until the \"%1\" command finishes.").arg( executable ), false );
connect( progressDlg, TQT_SIGNAL(cancelClicked()),
this, TQT_SLOT(cancelClicked()) );
}
diff --git a/lib/util/filetemplate.cpp b/lib/util/filetemplate.cpp
index e0425614..34165e84 100644
--- a/lib/util/filetemplate.cpp
+++ b/lib/util/filetemplate.cpp
@@ -23,7 +23,7 @@
#include <tqfile.h>
#include <tqfileinfo.h>
#include <tqregexp.h>
-#include <tqtextstream.h>
+#include <textstream.h>
#include <kstandarddirs.h>
@@ -69,8 +69,8 @@ TQString FileTemplate::makeSubstitutions( TQDomDocument & dom, const TQString &
TQString email = DomUtil::readEntry(dom, "/general/email");
TQString version = DomUtil::readEntry(dom, "/general/version");
TQString appname = DomUtil::readEntry(dom, "/general/projectname");
- TQString date = TQDate::tqcurrentDate().toString();
- TQString year = TQString::number(TQDate::tqcurrentDate().year());
+ TQString date = TQDate::currentDate().toString();
+ TQString year = TQString::number(TQDate::currentDate().year());
TQString str = text;
str.replace(TQRegExp("\\$EMAIL\\$"),email);
diff --git a/lib/util/kscriptactionmanager.cpp b/lib/util/kscriptactionmanager.cpp
index 3c906902..ffc3a536 100644
--- a/lib/util/kscriptactionmanager.cpp
+++ b/lib/util/kscriptactionmanager.cpp
@@ -95,7 +95,7 @@ void KScriptAction::activate( )
}
else
{
- KMessageBox::sorry(0, i18n("Unable to get KScript Runner for type \"%1\".").tqarg(m_scriptType), i18n("KScript Error"));
+ KMessageBox::sorry(0, i18n("Unable to get KScript Runner for type \"%1\".").arg(m_scriptType), i18n("KScript Error"));
kdDebug() << "Query string: " << scriptTypeQuery << endl;
return;
}
diff --git a/lib/util/settings.cpp b/lib/util/settings.cpp
index f91c91f0..c9087942 100644
--- a/lib/util/settings.cpp
+++ b/lib/util/settings.cpp
@@ -23,12 +23,12 @@ TQString Settings::terminalEmulatorName( KConfig & config )
if ( useKDESetting )
{
- KConfigGroup confGroup( KGlobal::config(), TQString::tqfromLatin1("General") );
- terminal = confGroup.readEntry("TerminalApplication", TQString::tqfromLatin1("konsole"));
+ KConfigGroup confGroup( KGlobal::config(), TQString::fromLatin1("General") );
+ terminal = confGroup.readEntry("TerminalApplication", TQString::fromLatin1("konsole"));
}
else
{
- terminal = config.readEntry( "TerminalApplication", TQString::tqfromLatin1("konsole"));
+ terminal = config.readEntry( "TerminalApplication", TQString::fromLatin1("konsole"));
}
return terminal;
}
diff --git a/lib/util/urlutil.cpp b/lib/util/urlutil.cpp
index 12b00065..81eecf84 100644
--- a/lib/util/urlutil.cpp
+++ b/lib/util/urlutil.cpp
@@ -303,7 +303,7 @@ TQString URLUtil::envExpand ( const TQString& str )
if (pos < 0)
pos = len;
- char* ret = getenv( TQConstString(str.tqunicode()+1, pos-1).string().local8Bit().data() );
+ char* ret = getenv( TQConstString(str.unicode()+1, pos-1).string().local8Bit().data() );
if (ret)
{
diff --git a/lib/widgets/fancylistviewitem.cpp b/lib/widgets/fancylistviewitem.cpp
index ef911ca0..6956636e 100644
--- a/lib/widgets/fancylistviewitem.cpp
+++ b/lib/widgets/fancylistviewitem.cpp
@@ -108,13 +108,13 @@ void FancyListViewItem::paintCell( TQPainter *painter, const TQColorGroup &cg,
if ( isEnabled() || !lv )
p->setPen( cg.highlightedText() );
else if ( !isEnabled() && lv)
- p->setPen( lv->tqpalette().disabled().highlightedText() );
+ p->setPen( lv->palette().disabled().highlightedText() );
}
{
if ( isEnabled() || !lv )
p->setPen( cg.text() );
else if ( !isEnabled() && lv)
- p->setPen( lv->tqpalette().disabled().text() );
+ p->setPen( lv->palette().disabled().text() );
int iconWidth = 0;
@@ -129,7 +129,7 @@ void FancyListViewItem::paintCell( TQPainter *painter, const TQColorGroup &cg,
else if ( align & AlignTop )
yo = 0;
-// respect horizontal tqalignment when there is no text for an item.
+// respect horizontal alignment when there is no text for an item.
if ( t.isEmpty() ) {
if ( align & AlignRight )
xo = width - 2 * marg - iconWidth;
diff --git a/lib/widgets/flagboxes.cpp b/lib/widgets/flagboxes.cpp
index 038d7936..648001b5 100644
--- a/lib/widgets/flagboxes.cpp
+++ b/lib/widgets/flagboxes.cpp
@@ -28,7 +28,7 @@
#include <tqtooltip.h>
#include <tqheader.h>
#include <tqstringlist.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqlabel.h>
#include <tqregexp.h>
#include <tqspinbox.h>
@@ -72,7 +72,7 @@ void FlagListToolTip::maybeTip(const TQPoint &pos)
FlagListItem *flitem = static_cast<FlagListItem*>(item);
if (item)
- tip(listbox->tqitemRect(item), flitem->desc);
+ tip(listbox->itemRect(item), flitem->desc);
}
@@ -306,22 +306,22 @@ FlagPathEdit::FlagPathEdit( TQWidget * parent, TQString pathDelimiter,
{
TQBoxLayout *topLayout = new TQVBoxLayout(this, 0, 1);
topLayout->addWidget(new TQLabel(description, this));
- TQBoxLayout *tqlayout = new TQHBoxLayout(topLayout, KDialog::spacingHint());
+ TQBoxLayout *layout = new TQHBoxLayout(topLayout, KDialog::spacingHint());
if (delimiter.isEmpty())
{
url = new KURLRequester(this);
url->setMode(mode);
- tqlayout->addWidget(url);
+ layout->addWidget(url);
}
else
{
edit = new KLineEdit(this);
- tqlayout->addWidget(edit);
+ layout->addWidget(edit);
details = new TQPushButton("...", this);
details->setMaximumWidth(30);
connect(details, TQT_SIGNAL(clicked()), this, TQT_SLOT(showPathDetails()));
- tqlayout->addWidget(details);
+ layout->addWidget(details);
}
TQApplication::sendPostedEvents(this, TQEvent::ChildInserted);
@@ -532,16 +532,16 @@ FlagListEdit::FlagListEdit( TQWidget * parent, TQString listDelimiter, FlagEditC
{
TQBoxLayout *topLayout = new TQVBoxLayout(this, 0, 1);
topLayout->addWidget(new TQLabel(description, this));
- TQBoxLayout *tqlayout = new TQHBoxLayout(topLayout, KDialog::spacingHint());
+ TQBoxLayout *layout = new TQHBoxLayout(topLayout, KDialog::spacingHint());
edit = new KLineEdit(this);
- tqlayout->addWidget(edit);
+ layout->addWidget(edit);
if (! listDelimiter.isEmpty())
{
details = new TQPushButton("...", this);
details->setMaximumWidth(30);
connect(details, TQT_SIGNAL(clicked()), this, TQT_SLOT(showListDetails()));
- tqlayout->addWidget(details);
+ layout->addWidget(details);
}
TQApplication::sendPostedEvents(this, TQEvent::ChildInserted);
@@ -624,7 +624,7 @@ void FlagSpinEdit::setText( const TQString text )
TQString FlagSpinEdit::text( )
{
- return TQString("%1").tqarg(spb->value());
+ return TQString("%1").arg(spb->value());
}
TQString FlagSpinEdit::flags( )
diff --git a/lib/widgets/kdevhtmlpart.cpp b/lib/widgets/kdevhtmlpart.cpp
index bb9bc892..bb476fdb 100644
--- a/lib/widgets/kdevhtmlpart.cpp
+++ b/lib/widgets/kdevhtmlpart.cpp
@@ -1,5 +1,5 @@
#include <tqfile.h>
-#include <tqclipboard.h>
+#include <clipboard.h>
#include <tqapplication.h>
#include <kxmlguiclient.h>
@@ -495,7 +495,7 @@ void KDevHTMLPart::slotCopy( )
{
TQString text = selectedText();
text.replace( TQChar( 0xa0 ), ' ' );
- TQClipboard *cb = TQApplication::tqclipboard();
+ TQClipboard *cb = TQApplication::clipboard();
disconnect( cb, TQT_SIGNAL( selectionChanged() ), this, TQT_SLOT( slotClearSelection() ) );
cb->setText(text);
connect( cb, TQT_SIGNAL( selectionChanged() ), this, TQT_SLOT( slotClearSelection() ) );
diff --git a/lib/widgets/processwidget.h b/lib/widgets/processwidget.h
index 5c33dd86..814db870 100644
--- a/lib/widgets/processwidget.h
+++ b/lib/widgets/processwidget.h
@@ -109,7 +109,7 @@ signals:
void rowSelected(int row);
protected:
- virtual TQSize tqminimumSizeHint() const;
+ virtual TQSize minimumSizeHint() const;
void maybeScrollToBottom();
protected slots:
diff --git a/lib/widgets/propeditor/pcheckbox.cpp b/lib/widgets/propeditor/pcheckbox.cpp
index 4a12d575..22c9a9c2 100644
--- a/lib/widgets/propeditor/pcheckbox.cpp
+++ b/lib/widgets/propeditor/pcheckbox.cpp
@@ -19,7 +19,7 @@
***************************************************************************/
#include "pcheckbox.h"
-#include <tqlayout.h>
+#include <layout.h>
#include <tqcheckbox.h>
#include <tqpainter.h>
@@ -36,7 +36,7 @@ PCheckBox::PCheckBox(MultiProperty *property, TQWidget *parent, const char *name
{
TQHBoxLayout *l = new TQHBoxLayout(this, 0, 0);
m_edit = new TQCheckBox(this);
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
l->addWidget(m_edit);
connect(m_edit, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(updateProperty(bool)));
diff --git a/lib/widgets/propeditor/pcolorbutton.cpp b/lib/widgets/propeditor/pcolorbutton.cpp
index bb927a08..5050791d 100644
--- a/lib/widgets/propeditor/pcolorbutton.cpp
+++ b/lib/widgets/propeditor/pcolorbutton.cpp
@@ -19,7 +19,7 @@
***************************************************************************/
#include "pcolorbutton.h"
-#include <tqlayout.h>
+#include <layout.h>
#include <tqpainter.h>
#ifndef PURE_QT
@@ -45,7 +45,7 @@ PColorButton::PColorButton(MultiProperty* property, TQWidget* parent, const char
connect(m_edit, TQT_SIGNAL(clicked()), this, TQT_SLOT(changeColor()));
#endif
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
l->addWidget(m_edit);
}
diff --git a/lib/widgets/propeditor/pcolorcombo.cpp b/lib/widgets/propeditor/pcolorcombo.cpp
index b0c82de3..73ad6bc8 100644
--- a/lib/widgets/propeditor/pcolorcombo.cpp
+++ b/lib/widgets/propeditor/pcolorcombo.cpp
@@ -19,7 +19,7 @@
***************************************************************************/
#include "pcolorcombo.h"
-#include <tqlayout.h>
+#include <layout.h>
#include <tqpainter.h>
#include <kcolorcombo.h>
@@ -31,7 +31,7 @@ PColorCombo::PColorCombo(MultiProperty *property, TQWidget *parent, const char *
{
TQHBoxLayout *l = new TQHBoxLayout(this, 0, 0);
m_edit = new KColorCombo(this);
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
l->addWidget(m_edit);
connect(m_edit, TQT_SIGNAL(activated(int)), this, TQT_SLOT(updateProperty(int)));
diff --git a/lib/widgets/propeditor/pcombobox.cpp b/lib/widgets/propeditor/pcombobox.cpp
index fa21678b..2ba2cd57 100644
--- a/lib/widgets/propeditor/pcombobox.cpp
+++ b/lib/widgets/propeditor/pcombobox.cpp
@@ -20,7 +20,7 @@
#include "pcombobox.h"
#include <tqcombobox.h>
-#include <tqlayout.h>
+#include <layout.h>
namespace PropertyLib{
@@ -40,7 +40,7 @@ void PComboBox::init(bool rw)
{
TQHBoxLayout *l = new TQHBoxLayout(this, 0, 0);
m_edit = new TQComboBox(rw, this);
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
l->addWidget(m_edit);
fillBox();
diff --git a/lib/widgets/propeditor/pdateedit.cpp b/lib/widgets/propeditor/pdateedit.cpp
index 64bbde18..ef96e430 100644
--- a/lib/widgets/propeditor/pdateedit.cpp
+++ b/lib/widgets/propeditor/pdateedit.cpp
@@ -21,7 +21,7 @@
#include <tqdatetimeedit.h>
#include <tqpainter.h>
-#include <tqlayout.h>
+#include <layout.h>
namespace PropertyLib{
@@ -30,7 +30,7 @@ PDateEdit::PDateEdit(MultiProperty* property, TQWidget* parent, const char* name
{
TQHBoxLayout *l = new TQHBoxLayout(this, 0, 0);
m_edit = new TQDateEdit(this);
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
l->addWidget(m_edit);
connect(m_edit, TQT_SIGNAL(valueChanged(const TQDate&)), this, TQT_SLOT(updateProperty(const TQDate&)));
diff --git a/lib/widgets/propeditor/pdatetimeedit.cpp b/lib/widgets/propeditor/pdatetimeedit.cpp
index 59df2440..0aa88262 100644
--- a/lib/widgets/propeditor/pdatetimeedit.cpp
+++ b/lib/widgets/propeditor/pdatetimeedit.cpp
@@ -21,7 +21,7 @@
#include <tqdatetimeedit.h>
#include <tqpainter.h>
-#include <tqlayout.h>
+#include <layout.h>
namespace PropertyLib{
@@ -29,7 +29,7 @@ PDateTimeEdit::PDateTimeEdit(MultiProperty* property, TQWidget* parent, const ch
{
TQHBoxLayout *l = new TQHBoxLayout(this, 0, 0);
m_edit = new TQDateTimeEdit(this);
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
l->addWidget(m_edit);
connect(m_edit, TQT_SIGNAL(valueChanged(const TQDateTime&)), this, TQT_SLOT(updateProperty(const TQDateTime&)));
diff --git a/lib/widgets/propeditor/pdoublenuminput.cpp b/lib/widgets/propeditor/pdoublenuminput.cpp
index e48475de..12c58616 100644
--- a/lib/widgets/propeditor/pdoublenuminput.cpp
+++ b/lib/widgets/propeditor/pdoublenuminput.cpp
@@ -27,7 +27,7 @@
#include <limits.h>
#include <math.h>
-#include <tqlayout.h>
+#include <layout.h>
namespace PropertyLib{
@@ -43,7 +43,7 @@ PDoubleNumInput::PDoubleNumInput(MultiProperty *property, TQWidget *parent, cons
m_edit = new TQFloatInput(-999999, 999999, 0.01, 2, this );
connect(m_edit, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(updateProperty(int)));
#endif
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
/* m_edit->setMinValue(-999999999);
m_edit->setMaxValue(+999999999);
m_edit->setPrecision(2);*/
@@ -78,7 +78,7 @@ void PDoubleNumInput::updateProperty(double val)
void PDoubleNumInput::updateProperty(int val)
{
#ifdef PURE_QT
- TQString format = TQString("%.%1f").tqarg( m_edit->digits() );
+ TQString format = TQString("%.%1f").arg( m_edit->digits() );
TQString strVal = TQString().sprintf(format.latin1(),
(val/(float)pow(m_edit->digits(),10)) );
emit propertyChanged(m_property, TQVariant(strVal));
diff --git a/lib/widgets/propeditor/pfontbutton.cpp b/lib/widgets/propeditor/pfontbutton.cpp
index e54e401f..edfb0b3c 100644
--- a/lib/widgets/propeditor/pfontbutton.cpp
+++ b/lib/widgets/propeditor/pfontbutton.cpp
@@ -19,7 +19,7 @@
***************************************************************************/
#include "pfontbutton.h"
-#include <tqlayout.h>
+#include <layout.h>
#include <tqpainter.h>
#include <tqpushbutton.h>
@@ -38,7 +38,7 @@ PFontButton::PFontButton(MultiProperty* property, TQWidget* parent, const char*
{
TQHBoxLayout *l = new TQHBoxLayout(this, 0, 0);
m_edit = new KFontRequester(this);
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
#ifndef PURE_QT
m_edit->button()->setText(i18n("..."));
#endif
@@ -61,7 +61,7 @@ void PFontButton::drawViewer(TQPainter* p, const TQColorGroup& cg, const TQRect&
p->drawText(r, TQt::AlignLeft | TQt::AlignVCenter | TQt::SingleLine,
fi.family() + (fi.bold() ? i18n(" Bold") : TQString("")) +
(fi.italic() ? i18n(" Italic") : TQString("")) +
- " " + TQString("%1").tqarg(fi.pointSize()) );
+ " " + TQString("%1").arg(fi.pointSize()) );
}
void PFontButton::setValue(const TQVariant& value, bool emitChange)
diff --git a/lib/widgets/propeditor/pfontcombo.cpp b/lib/widgets/propeditor/pfontcombo.cpp
index 51b44e8c..2e5a5da3 100644
--- a/lib/widgets/propeditor/pfontcombo.cpp
+++ b/lib/widgets/propeditor/pfontcombo.cpp
@@ -25,7 +25,7 @@
#include <tqcombobox.h>
#endif
-#include <tqlayout.h>
+#include <layout.h>
#ifdef PURE_QT
#include <tqfontdatabase.h>
@@ -38,7 +38,7 @@ PFontCombo::PFontCombo(MultiProperty *property, TQWidget *parent, const char *na
{
TQHBoxLayout *l = new TQHBoxLayout(this, 0, 0);
m_edit = new KFontCombo(this);
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
l->addWidget(m_edit);
/*adymo: KFontCombo seems to have a bug: when it is not editable, the signals
diff --git a/lib/widgets/propeditor/plineedit.cpp b/lib/widgets/propeditor/plineedit.cpp
index 2c4fabc9..3d28a6da 100644
--- a/lib/widgets/propeditor/plineedit.cpp
+++ b/lib/widgets/propeditor/plineedit.cpp
@@ -20,7 +20,7 @@
#include "plineedit.h"
#include <klineedit.h>
-#include <tqlayout.h>
+#include <layout.h>
namespace PropertyLib{
@@ -29,7 +29,7 @@ PLineEdit::PLineEdit(MultiProperty *property, TQWidget *parent, const char *name
{
TQHBoxLayout *l = new TQHBoxLayout(this, 0, 0);
m_edit = new KLineEdit(this);
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
l->addWidget(m_edit);
connect(m_edit, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(updateProperty(const TQString&)));
diff --git a/lib/widgets/propeditor/plinestyleedit.cpp b/lib/widgets/propeditor/plinestyleedit.cpp
index a47dc614..3fc3315a 100644
--- a/lib/widgets/propeditor/plinestyleedit.cpp
+++ b/lib/widgets/propeditor/plinestyleedit.cpp
@@ -22,7 +22,7 @@
#include <tqpainter.h>
#include <tqpixmap.h>
#include <tqcombobox.h>
-#include <tqlayout.h>
+#include <layout.h>
namespace PropertyLib {
@@ -131,7 +131,7 @@ PLineStyleEdit::PLineStyleEdit(MultiProperty* property, TQWidget* parent, const
{
TQHBoxLayout *l = new TQHBoxLayout(this, 0, 0);
m_edit = new TQComboBox(this);
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
l->addWidget(m_edit);
m_edit->insertItem(TQPixmap(nopen));
diff --git a/lib/widgets/propeditor/ppixmapedit.cpp b/lib/widgets/propeditor/ppixmapedit.cpp
index 20f943e8..6217ed07 100644
--- a/lib/widgets/propeditor/ppixmapedit.cpp
+++ b/lib/widgets/propeditor/ppixmapedit.cpp
@@ -21,7 +21,7 @@
***************************************************************************/
#include "ppixmapedit.h"
-#include <tqlayout.h>
+#include <layout.h>
#include <tqpainter.h>
#include <tqlabel.h>
#include <tqcursor.h>
@@ -46,7 +46,7 @@ PPixmapEdit::PPixmapEdit(MultiProperty* property, TQWidget* parent, const char*
{
TQHBoxLayout *l = new TQHBoxLayout(this, 0, 0);
m_edit = new TQLabel(this);
- m_edit->tqsetAlignment(TQt::AlignTop);
+ m_edit->setAlignment(TQt::AlignTop);
m_edit->resize(width(), height()-1);
m_edit->setBackgroundMode(TQt::PaletteBase);
m_edit->installEventFilter(this);
@@ -54,7 +54,7 @@ PPixmapEdit::PPixmapEdit(MultiProperty* property, TQWidget* parent, const char*
m_button = new TQPushButton(i18n("..."), this);
m_button->resize(height(), height()-8);
m_button->move(width() - m_button->width() -1, 0);
- m_button->tqsetSizePolicy(TQSizePolicy::Maximum, TQSizePolicy::Fixed);
+ m_button->setSizePolicy(TQSizePolicy::Maximum, TQSizePolicy::Fixed);
l->addWidget(m_edit);
l->addWidget(m_button);
m_popup = new TQLabel(0, 0, TQt::WStyle_NoBorder|TQt::WX11BypassWM|WStyle_StaysOnTop);
diff --git a/lib/widgets/propeditor/ppointedit.cpp b/lib/widgets/propeditor/ppointedit.cpp
index 4e85d214..950da89b 100644
--- a/lib/widgets/propeditor/ppointedit.cpp
+++ b/lib/widgets/propeditor/ppointedit.cpp
@@ -20,7 +20,7 @@
#include "ppointedit.h"
#include <klineedit.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqpainter.h>
namespace PropertyLib{
@@ -29,7 +29,7 @@ PPointEdit::PPointEdit(MultiProperty* property, TQWidget* parent, const char* na
{
TQHBoxLayout *l = new TQHBoxLayout(this, 0, 0);
m_edit = new KLineEdit(this);
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
l->addWidget(m_edit);
m_edit->setReadOnly(true);
@@ -45,13 +45,13 @@ void PPointEdit::drawViewer(TQPainter* p, const TQColorGroup& cg, const TQRect&
p->setPen(TQt::NoPen);
p->setBrush(cg.background());
p->drawRect(r);
- p->drawText(r, TQt::AlignLeft | TQt::AlignVCenter | TQt::SingleLine, TQString("[ %1, %2 ]").tqarg(value.toPoint().x()).tqarg(value.toPoint().y()));
+ p->drawText(r, TQt::AlignLeft | TQt::AlignVCenter | TQt::SingleLine, TQString("[ %1, %2 ]").arg(value.toPoint().x()).arg(value.toPoint().y()));
}
void PPointEdit::setValue(const TQVariant& value, bool emitChange)
{
m_value = value;
- m_edit->setText(TQString("[ %1, %2 ]").tqarg(value.toPoint().x()).tqarg(value.toPoint().y()));
+ m_edit->setText(TQString("[ %1, %2 ]").arg(value.toPoint().x()).arg(value.toPoint().y()));
if (emitChange)
emit propertyChanged(m_property, value);
diff --git a/lib/widgets/propeditor/prectedit.cpp b/lib/widgets/propeditor/prectedit.cpp
index d7a5fa01..c9f5388e 100644
--- a/lib/widgets/propeditor/prectedit.cpp
+++ b/lib/widgets/propeditor/prectedit.cpp
@@ -20,7 +20,7 @@
#include "prectedit.h"
#include <klineedit.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqpainter.h>
namespace PropertyLib{
@@ -29,7 +29,7 @@ PRectEdit::PRectEdit(MultiProperty* property, TQWidget* parent, const char* name
{
TQHBoxLayout *l = new TQHBoxLayout(this, 0, 0);
m_edit = new KLineEdit(this);
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
l->addWidget(m_edit);
m_edit->setReadOnly(true);
@@ -45,13 +45,13 @@ void PRectEdit::drawViewer(TQPainter* p, const TQColorGroup& cg, const TQRect& r
p->setPen(TQt::NoPen);
p->setBrush(cg.background());
p->drawRect(r);
- p->drawText(r, TQt::AlignLeft | TQt::AlignVCenter | TQt::SingleLine, TQString("[ %1, %2, %3, %4 ]").tqarg(value.toRect().x()).tqarg(value.toRect().y()).tqarg(value.toRect().width()).tqarg(value.toRect().height()));
+ p->drawText(r, TQt::AlignLeft | TQt::AlignVCenter | TQt::SingleLine, TQString("[ %1, %2, %3, %4 ]").arg(value.toRect().x()).arg(value.toRect().y()).arg(value.toRect().width()).arg(value.toRect().height()));
}
void PRectEdit::setValue(const TQVariant& value, bool emitChange)
{
m_value = value;
- m_edit->setText(TQString("[ %1, %2, %3, %4 ]").tqarg(value.toRect().x()).tqarg(value.toRect().y()).tqarg(value.toRect().width()).tqarg(value.toRect().height()));
+ m_edit->setText(TQString("[ %1, %2, %3, %4 ]").arg(value.toRect().x()).arg(value.toRect().y()).arg(value.toRect().width()).arg(value.toRect().height()));
if (emitChange)
emit propertyChanged(m_property, value);
diff --git a/lib/widgets/propeditor/property.h b/lib/widgets/propeditor/property.h
index 48c6987f..a94ea4cb 100644
--- a/lib/widgets/propeditor/property.h
+++ b/lib/widgets/propeditor/property.h
@@ -105,7 +105,7 @@ public:
//predefined custom types
ValueFromList = 2000 /**<string value from a list*/,
- Symbol = 2001 /**<tqunicode symbol code*/,
+ Symbol = 2001 /**<unicode symbol code*/,
FontName = 2002 /**<font name, e.g. "times new roman"*/,
FileURL = 2003 /**<url of a file*/,
DirectoryURL = 2004 /**<url of a directory*/,
diff --git a/lib/widgets/propeditor/propertyeditor.cpp b/lib/widgets/propeditor/propertyeditor.cpp
index ed7b81f2..bda2077c 100644
--- a/lib/widgets/propeditor/propertyeditor.cpp
+++ b/lib/widgets/propeditor/propertyeditor.cpp
@@ -28,7 +28,7 @@
#endif
#include <tqtable.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqpainter.h>
#include <tqptrlist.h>
#include <tqvaluelist.h>
@@ -196,7 +196,7 @@ PropertyEditor::PropertyEditor(TQWidget *parent, const char *name)
#else
m_undoButton->setPixmap( TQPixmap("undo.xpm") );
#endif
- m_undoButton->tqsetSizePolicy(TQSizePolicy::Maximum, TQSizePolicy::MinimumExpanding);
+ m_undoButton->setSizePolicy(TQSizePolicy::Maximum, TQSizePolicy::MinimumExpanding);
m_undoButton->resize(m_undoButton->height(), m_undoButton->height());
m_undoButton->hide();
connect(m_undoButton, TQT_SIGNAL(clicked()), this, TQT_SLOT(undo()));
@@ -270,7 +270,7 @@ void PropertyEditor::addChildProperties(PropertyItem *parent)
machine(prop);
}
-// qWarning("seeking tqchildren: count: %d", prop->details.count());
+// qWarning("seeking children: count: %d", prop->details.count());
parent->setOpen(true);
for (TQValueList<ChildProperty>::iterator it = prop->details.begin(); it != prop->details.end(); ++it)
@@ -301,7 +301,7 @@ void PropertyEditor::propertyValueChanged(Property *property)
m_currentEditWidget->setValue(property->value(), false);
else
{
-// tqrepaint all items
+// repaint all items
TQListViewItemIterator it(this);
while (it.current())
{
@@ -360,11 +360,11 @@ void PropertyEditor::showEditor(PropertyItem *item)
void PropertyEditor::placeEditor(PropertyItem *item)
{
- TQRect r = tqitemRect(item);
+ TQRect r = itemRect(item);
if (!r.size().isValid())
{
ensureItemVisible(item);
- r = tqitemRect(item);
+ r = itemRect(item);
}
r.setX(header()->sectionPos(1));
@@ -386,7 +386,7 @@ void PropertyEditor::placeEditor(PropertyItem *item)
m_currentEditLayout->addWidget(editor, 0, 0);
m_currentEditLayout->addWidget(m_undoButton, 0, 1);
m_currentEditArea->resize(r.size());
-// m_currentEditLayout->tqinvalidate();
+// m_currentEditLayout->invalidate();
moveChild(m_currentEditArea, r.x(), r.y());
m_currentEditWidget = editor;
}
@@ -447,7 +447,7 @@ Machine *PropertyEditor::machine(MultiProperty *property)
m_registeredForType[name] = PropertyMachineFactory::getInstance()->machineForProperty(property);
connect(m_registeredForType[name]->propertyEditor, TQT_SIGNAL(propertyChanged(MultiProperty*, const TQVariant&)),
this, TQT_SLOT(propertyChanged(MultiProperty*, const TQVariant&)));
- m_registeredForType[name]->propertyEditor->reparent(m_currentEditArea, 0, m_currentEditArea->tqchildrenRect().topLeft());
+ m_registeredForType[name]->propertyEditor->reparent(m_currentEditArea, 0, m_currentEditArea->childrenRect().topLeft());
m_registeredForType[name]->propertyEditor->hide();
}
return m_registeredForType[name];
diff --git a/lib/widgets/propeditor/propertywidgetproxy.cpp b/lib/widgets/propeditor/propertywidgetproxy.cpp
index 813708ca..c891672e 100644
--- a/lib/widgets/propeditor/propertywidgetproxy.cpp
+++ b/lib/widgets/propeditor/propertywidgetproxy.cpp
@@ -19,7 +19,7 @@
***************************************************************************/
#include "propertywidgetproxy.h"
-#include <tqlayout.h>
+#include <layout.h>
#include "propertywidget.h"
#include "propertymachinefactory.h"
diff --git a/lib/widgets/propeditor/psizeedit.cpp b/lib/widgets/propeditor/psizeedit.cpp
index 5558c3f3..1077a4be 100644
--- a/lib/widgets/propeditor/psizeedit.cpp
+++ b/lib/widgets/propeditor/psizeedit.cpp
@@ -20,7 +20,7 @@
#include "psizeedit.h"
#include <klineedit.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqpainter.h>
namespace PropertyLib{
@@ -30,7 +30,7 @@ PSizeEdit::PSizeEdit(MultiProperty *property, TQWidget *parent, const char *name
{
TQHBoxLayout *l = new TQHBoxLayout(this, 0, 0);
m_edit = new KLineEdit(this);
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
l->addWidget(m_edit);
m_edit->setReadOnly(true);
@@ -46,13 +46,13 @@ void PSizeEdit::drawViewer(TQPainter* p, const TQColorGroup& cg, const TQRect& r
p->setPen(TQt::NoPen);
p->setBrush(cg.background());
p->drawRect(r);
- p->drawText(r, TQt::AlignLeft | TQt::AlignVCenter | TQt::SingleLine, TQString("[ %1, %2 ]").tqarg(value.toSize().width()).tqarg(value.toSize().height()));
+ p->drawText(r, TQt::AlignLeft | TQt::AlignVCenter | TQt::SingleLine, TQString("[ %1, %2 ]").arg(value.toSize().width()).arg(value.toSize().height()));
}
void PSizeEdit::setValue(const TQVariant& value, bool emitChange)
{
m_value = value;
- m_edit->setText(TQString("[ %1, %2 ]").tqarg(value.toSize().width()).tqarg(value.toSize().height()));
+ m_edit->setText(TQString("[ %1, %2 ]").arg(value.toSize().width()).arg(value.toSize().height()));
if (emitChange)
emit propertyChanged(m_property, value);
diff --git a/lib/widgets/propeditor/psizepolicyedit.cpp b/lib/widgets/propeditor/psizepolicyedit.cpp
index 94847d2a..640c873f 100644
--- a/lib/widgets/propeditor/psizepolicyedit.cpp
+++ b/lib/widgets/propeditor/psizepolicyedit.cpp
@@ -20,7 +20,7 @@
#include "psizepolicyedit.h"
#include <klineedit.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqpainter.h>
#include <tqsizepolicy.h>
@@ -31,7 +31,7 @@ PSizePolicyEdit::PSizePolicyEdit(MultiProperty* property, const TQMap<TQString,
{
TQHBoxLayout *l = new TQHBoxLayout(this, 0, 0);
m_edit = new KLineEdit(this);
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
l->addWidget(m_edit);
m_edit->setReadOnly(true);
@@ -47,13 +47,13 @@ void PSizePolicyEdit::drawViewer(TQPainter* p, const TQColorGroup& cg, const TQR
p->setPen(TQt::NoPen);
p->setBrush(cg.background());
p->drawRect(r);
- p->drawText(r, TQt::AlignLeft | TQt::AlignVCenter | TQt::SingleLine, TQString("%1/%2/%3/%4").tqarg(findValueDescription(value.toSizePolicy().horData())).tqarg(findValueDescription(value.toSizePolicy().verData())).tqarg(value.toSizePolicy().horStretch()).tqarg(value.toSizePolicy().verStretch()));
+ p->drawText(r, TQt::AlignLeft | TQt::AlignVCenter | TQt::SingleLine, TQString("%1/%2/%3/%4").arg(findValueDescription(value.toSizePolicy().horData())).arg(findValueDescription(value.toSizePolicy().verData())).arg(value.toSizePolicy().horStretch()).arg(value.toSizePolicy().verStretch()));
}
void PSizePolicyEdit::setValue(const TQVariant& value, bool emitChange)
{
m_value = value;
- m_edit->setText(TQString("%1/%2/%3/%4").tqarg(findValueDescription(value.toSizePolicy().horData())).tqarg(findValueDescription(value.toSizePolicy().verData())).tqarg(value.toSizePolicy().horStretch()).tqarg(value.toSizePolicy().verStretch()));
+ m_edit->setText(TQString("%1/%2/%3/%4").arg(findValueDescription(value.toSizePolicy().horData())).arg(findValueDescription(value.toSizePolicy().verData())).arg(value.toSizePolicy().horStretch()).arg(value.toSizePolicy().verStretch()));
if (emitChange)
emit propertyChanged(m_property, value);
diff --git a/lib/widgets/propeditor/pspinbox.cpp b/lib/widgets/propeditor/pspinbox.cpp
index e9c25325..3dfc5abe 100644
--- a/lib/widgets/propeditor/pspinbox.cpp
+++ b/lib/widgets/propeditor/pspinbox.cpp
@@ -22,7 +22,7 @@
#include <limits.h>
#include <tqspinbox.h>
-#include <tqlayout.h>
+#include <layout.h>
namespace PropertyLib{
@@ -31,7 +31,7 @@ PSpinBox::PSpinBox(MultiProperty *property, TQWidget *parent, const char *name)
{
TQHBoxLayout *l = new TQHBoxLayout(this, 0, 0);
m_edit = new TQSpinBox(INT_MIN, INT_MAX, 1, this);
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
l->addWidget(m_edit);
connect(m_edit, TQT_SIGNAL(valueChanged(int)), this, TQT_SLOT(updateProperty(int)));
diff --git a/lib/widgets/propeditor/pstringlistedit.cpp b/lib/widgets/propeditor/pstringlistedit.cpp
index fda16a8b..2b0fc8f8 100644
--- a/lib/widgets/propeditor/pstringlistedit.cpp
+++ b/lib/widgets/propeditor/pstringlistedit.cpp
@@ -19,7 +19,7 @@
***************************************************************************/
#include "pstringlistedit.h"
-#include <tqlayout.h>
+#include <layout.h>
#include <tqdialog.h>
#include <tqpainter.h>
#include <klineedit.h>
@@ -43,10 +43,10 @@ PStringListEdit::PStringListEdit(MultiProperty *property, TQWidget *parent, cons
edit = new KLineEdit(this);
edit->setReadOnly(true);
- edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
l->addWidget(edit);
pbSelect = new TQPushButton("...", this);
- pbSelect->tqsetSizePolicy(TQSizePolicy::Maximum, TQSizePolicy::MinimumExpanding);
+ pbSelect->setSizePolicy(TQSizePolicy::Maximum, TQSizePolicy::MinimumExpanding);
l->addWidget(pbSelect);
connect(pbSelect, TQT_SIGNAL(clicked()), this, TQT_SLOT(showEditor()));
diff --git a/lib/widgets/propeditor/psymbolcombo.cpp b/lib/widgets/propeditor/psymbolcombo.cpp
index 7e79945a..25fe3ebd 100644
--- a/lib/widgets/propeditor/psymbolcombo.cpp
+++ b/lib/widgets/propeditor/psymbolcombo.cpp
@@ -18,7 +18,7 @@
* 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA. *
***************************************************************************/
-#include <tqlayout.h>
+#include <layout.h>
#include <tqpainter.h>
#include <tqpushbutton.h>
#include <klineedit.h>
@@ -40,11 +40,11 @@ PSymbolCombo::PSymbolCombo(MultiProperty *property, TQWidget *parent, const char
{
l = new TQHBoxLayout(this);
m_edit = new KLineEdit(this);
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
m_edit->setMaxLength(1);
l->addWidget(m_edit);
m_select = new TQPushButton("...", this);
- m_select->tqsetSizePolicy(TQSizePolicy::Maximum, TQSizePolicy::MinimumExpanding);
+ m_select->setSizePolicy(TQSizePolicy::Maximum, TQSizePolicy::MinimumExpanding);
l->addWidget(m_select);
#ifdef PURE_QT
@@ -58,7 +58,7 @@ PSymbolCombo::PSymbolCombo(MultiProperty *property, TQWidget *parent, const char
TQVariant PSymbolCombo::value() const
{
if (!(m_edit->text().isNull()))
- return TQVariant(TQString("%1").tqarg(m_edit->text().tqat(0).tqunicode()));
+ return TQVariant(TQString("%1").arg(m_edit->text().at(0).unicode()));
else
return TQVariant(0);
}
@@ -109,7 +109,7 @@ void PSymbolCombo::selectChar()
void PSymbolCombo::updateProperty(const TQString& val)
{
- emit propertyChanged(m_property, TQVariant(TQString("%1").tqarg(val.tqat(0).tqunicode())));
+ emit propertyChanged(m_property, TQVariant(TQString("%1").arg(val.at(0).unicode())));
}
void PSymbolCombo::drawViewer(TQPainter *p, const TQColorGroup &cg, const TQRect &r, const TQVariant &value)
diff --git a/lib/widgets/propeditor/purledit.cpp b/lib/widgets/propeditor/purledit.cpp
index df8316cd..0625aa38 100644
--- a/lib/widgets/propeditor/purledit.cpp
+++ b/lib/widgets/propeditor/purledit.cpp
@@ -26,7 +26,7 @@
#include <tqlineedit.h>
#endif
#include <tqfiledialog.h>
-#include <tqlayout.h>
+#include <layout.h>
namespace PropertyLib{
@@ -47,7 +47,7 @@ PUrlEdit::PUrlEdit(Mode mode, MultiProperty* property, TQWidget* parent, const c
m_mode = mode;
connect( m_select, TQT_SIGNAL(clicked()),this,TQT_SLOT(select()));
#endif
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
}
TQVariant PUrlEdit::value() const
diff --git a/lib/widgets/propeditor/pyesnobutton.cpp b/lib/widgets/propeditor/pyesnobutton.cpp
index 614b751b..7e96f772 100644
--- a/lib/widgets/propeditor/pyesnobutton.cpp
+++ b/lib/widgets/propeditor/pyesnobutton.cpp
@@ -19,7 +19,7 @@
***************************************************************************/
#include "pyesnobutton.h"
-#include <tqlayout.h>
+#include <layout.h>
#include <tqpainter.h>
#include <tqpushbutton.h>
@@ -37,7 +37,7 @@ PYesNoButton::PYesNoButton(MultiProperty* property, TQWidget* parent, const char
TQHBoxLayout *l = new TQHBoxLayout(this, 0, 0);
m_edit = new TQPushButton(this);
m_edit->setToggleButton(true);
- m_edit->tqsetSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
+ m_edit->setSizePolicy(TQSizePolicy::MinimumExpanding, TQSizePolicy::MinimumExpanding);
l->addWidget(m_edit);
connect(m_edit, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(updateProperty(bool)));
diff --git a/lib/widgets/propeditor/qeditlistbox.cpp b/lib/widgets/propeditor/qeditlistbox.cpp
index fda5a006..d8c8bcdf 100644
--- a/lib/widgets/propeditor/qeditlistbox.cpp
+++ b/lib/widgets/propeditor/qeditlistbox.cpp
@@ -24,7 +24,7 @@
#include <klineedit.h>
#include <tqpushbutton.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqgroupbox.h>
#include <tqlistbox.h>
#include <tqwhatsthis.h>
@@ -92,7 +92,7 @@ void QEditListBox::init( bool checkAtEntering, int buttons,
servNewButton = servRemoveButton = servUpButton = servDownButton = 0L;
- tqsetSizePolicy(TQSizePolicy(TQSizePolicy::MinimumExpanding,
+ setSizePolicy(TQSizePolicy(TQSizePolicy::MinimumExpanding,
TQSizePolicy::MinimumExpanding));
TQWidget * gb = this;
diff --git a/lib/widgets/propeditor/qfloatinput.cpp b/lib/widgets/propeditor/qfloatinput.cpp
index 1922ea6a..f2fefed8 100644
--- a/lib/widgets/propeditor/qfloatinput.cpp
+++ b/lib/widgets/propeditor/qfloatinput.cpp
@@ -38,7 +38,7 @@ TQFloatInput::TQFloatInput( int min, int max, float step, int digits,
TQString TQFloatInput::mapValueToText( int value )
{
- TQString format = TQString("%.%1f").tqarg( m_digits );
+ TQString format = TQString("%.%1f").arg( m_digits );
return TQString().sprintf(format.latin1(),
(value/(float)pow(m_digits,10)) );
}
diff --git a/lib/widgets/qcomboview.h b/lib/widgets/qcomboview.h
index ecfa8ee2..35eef4f1 100644
--- a/lib/widgets/qcomboview.h
+++ b/lib/widgets/qcomboview.h
@@ -68,7 +68,7 @@ public:
bool autoResize() const;
virtual void setAutoResize( bool );
- TQSize tqsizeHint() const;
+ TQSize sizeHint() const;
void setPalette( const TQPalette & );
void setFont( const TQFont & );
diff --git a/lib/widgets/resizablecombo.cpp b/lib/widgets/resizablecombo.cpp
index aba2f658..3e2df727 100644
--- a/lib/widgets/resizablecombo.cpp
+++ b/lib/widgets/resizablecombo.cpp
@@ -21,7 +21,7 @@
#include "kcomboview.h"
#include <tqevent.h>
-#include <tqlayout.h>
+#include <layout.h>
#include <tqpixmap.h>
#include <tqapplication.h>
#include <tqwhatsthis.h>
diff --git a/lib/widgets/processwidget.cpp b/lib/widgets/processwidget.cpp
index 1b4cb3ab..f28e4ec7 100644
--- a/lib/widgets/processwidget.cpp
+++ b/lib/widgets/processwidget.cpp
@@ -73,7 +73,7 @@ void ProcessListBoxItem::paint(TQPainter *p)
{
TQColor dim, warn, err, back;
if (listBox()) {
- const TQColorGroup& group = listBox()->tqpalette().active();
+ const TQColorGroup& group = listBox()->palette().active();
if (isSelected()) {
back = group.button();
warn = group.buttonText();
@@ -227,7 +227,7 @@ void ProcessWidget::childFinished(bool normal, int status)
if (normal) {
if (status) {
- s = i18n("*** Exited with status: %1 ***").tqarg(status);
+ s = i18n("*** Exited with status: %1 ***").arg(status);
t = ProcessListBoxItem::Error;
} else {
s = i18n("*** Exited normally ***");
@@ -249,12 +249,12 @@ void ProcessWidget::childFinished(bool normal, int status)
}
-TQSize ProcessWidget::tqminimumSizeHint() const
+TQSize ProcessWidget::minimumSizeHint() const
{
// I'm not sure about this, but when I don't use override tqminimumSizeHint(),
// the initial size in clearly too small
- return TQSize( TQListBox::tqsizeHint().width(),
+ return TQSize( TQListBox::sizeHint().width(),
(fontMetrics().lineSpacing()+2)*4 );
}
@@ -249,12 +249,12 @@ void ProcessWidget::childFinished(bool normal, int status)
{
- // I'm not sure about this, but when I don't use override tqminimumSizeHint(),
+ // I'm not sure about this, but when I don't use override minimumSizeHint(),
// the initial size in clearly too small
diff --git a/lib/widgets/qcomboview.cpp b/lib/widgets/qcomboview.cpp
index 2dcfb9f3..113c8d38 100644
--- a/lib/widgets/qcomboview.cpp
+++ b/lib/widgets/qcomboview.cpp
@@ -39,7 +39,7 @@ public:
QComboViewData( QComboView *cb ): current(0), lView( 0 ), combo( cb )
{
duplicatesEnabled = TRUE;
- cb->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Fixed ) );
+ cb->setSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Fixed ) );
}
inline TQListView * listView() { return lView; }
@@ -68,7 +68,7 @@ public:
TQLineEdit * ed; // /bin/ed rules!
TQTimer *completionTimer;
- TQSize tqsizeHint;
+ TQSize sizeHint;
private:
bool usinglView;
@@ -81,14 +81,14 @@ void QComboViewData::updateLinedGeometry()
{
if ( !ed || !combo )
return;
- TQRect r = TQStyle::tqvisualRect( combo->tqstyle().querySubControlMetrics(TQStyle::CC_ComboBox, combo,
+ TQRect r = TQStyle::visualRect( combo->tqstyle().querySubControlMetrics(TQStyle::CC_ComboBox, combo,
TQStyle::SC_ComboBoxEditField), combo );
// qWarning("updateLinedGeometry(): currentItem is %d", combo->currentItem() == 0 ? 0 : 1);
const TQPixmap *pix = combo->currentItem() ? combo->currentItem()->pixmap(0) : 0;
if ( pix && pix->width() < r.width() )
r.setLeft( r.left() + pix->width() + 4 );
- if ( r != ed->tqgeometry() )
+ if ( r != ed->geometry() )
ed->setGeometry( r );
}
@@ -204,7 +204,7 @@ void QComboView::clear()
d->current = 0;
if ( d->ed ) {
- d->ed->setText( TQString::tqfromLatin1("") );
+ d->ed->setText( TQString::fromLatin1("") );
d->updateLinedGeometry();
}
currentChanged();
@@ -269,13 +269,13 @@ void QComboView::setAutoResize( bool enable )
reimp
This implementation caches the size hint to avoid resizing when
- the contents change dynamically. To tqinvalidate the cached value
+ the contents change dynamically. To invalidate the cached value
call setFont().
*/
-TQSize QComboView::tqsizeHint() const
+TQSize QComboView::sizeHint() const
{
- if ( isVisible() && d->tqsizeHint.isValid() )
- return d->tqsizeHint;
+ if ( isVisible() && d->sizeHint.isValid() )
+ return d->sizeHint;
constPolish();
// int i, w;
@@ -290,10 +290,10 @@ TQSize QComboView::tqsizeHint() const
maxW = w;
}
*/
- d->tqsizeHint = (tqstyle().tqsizeFromContents(TQStyle::CT_ComboBox, this,
+ d->sizeHint = (tqstyle().tqsizeFromContents(TQStyle::CT_ComboBox, this,
TQSize(maxW, maxH)).expandedTo(TQApplication::globalStrut()));
- return d->tqsizeHint;
+ return d->sizeHint;
}
@@ -385,7 +385,7 @@ void QComboView::setPalette( const TQPalette &palette )
void QComboView::setFont( const TQFont &font )
{
- d->tqsizeHint = TQSize(); // tqinvalidate size hint
+ d->sizeHint = TQSize(); // invalidate size hint
TQWidget::setFont( font );
d->listView()->setFont( font );
if (d->ed)
@@ -412,7 +412,7 @@ void QComboView::resizeEvent( TQResizeEvent * e )
void QComboView::paintEvent( TQPaintEvent * )
{
TQPainter p( this );
- const TQColorGroup & g = tqcolorGroup();
+ const TQColorGroup & g = colorGroup();
p.setPen(g.text());
TQStyle::SFlags flags = TQStyle::Style_Default;
@@ -428,7 +428,7 @@ void QComboView::paintEvent( TQPaintEvent * )
}
// bool reverse = TQApplication::reverseLayout();
- tqstyle().tqdrawComplexControl( TQStyle::CC_ComboBox, &p, this, rect(), g,
+ tqstyle().drawComplexControl( TQStyle::CC_ComboBox, &p, this, rect(), g,
flags, TQStyle::SC_All,
(d->arrowDown ?
TQStyle::SC_ComboBoxArrow :
@@ -436,7 +436,7 @@ void QComboView::paintEvent( TQPaintEvent * )
TQRect re = tqstyle().querySubControlMetrics( TQStyle::CC_ComboBox, this,
TQStyle::SC_ComboBoxEditField );
- re = TQStyle::tqvisualRect(re, this);
+ re = TQStyle::visualRect(re, this);
p.setClipRect( re );
if ( !d->ed ) {
@@ -445,14 +445,14 @@ void QComboView::paintEvent( TQPaintEvent * )
// we calculate the TQListBoxTexts height (ignoring strut)
int itemh = d->listView()->fontMetrics().lineSpacing() + 2;
p.translate( re.x(), re.y() + (re.height() - itemh)/2 );
- item->paintCell( &p, d->listView()->tqcolorGroup(), 0, width(), AlignLeft | AlignVCenter );
+ item->paintCell( &p, d->listView()->colorGroup(), 0, width(), AlignLeft | AlignVCenter );
}
} else if ( d->listView() && d->listView()->currentItem( ) && d->current ) {
TQListViewItem * item = d->current ;
const TQPixmap *pix = item->pixmap(0);
if ( pix ) {
p.fillRect( re.x(), re.y(), pix->width() + 4, re.height(),
- tqcolorGroup().brush( TQColorGroup::Base ) );
+ colorGroup().brush( TQColorGroup::Base ) );
p.drawPixmap( re.x() + 2, re.y() +
( re.height() - pix->height() ) / 2, *pix );
}
@@ -474,7 +474,7 @@ void QComboView::mousePressEvent( TQMouseEvent *e )
}
TQRect arrowRect = tqstyle().querySubControlMetrics( TQStyle::CC_ComboBox, this,
TQStyle::SC_ComboBoxArrow);
- arrowRect = TQStyle::tqvisualRect(arrowRect, this);
+ arrowRect = TQStyle::visualRect(arrowRect, this);
// Correction for motif style, where arrow is smaller
// and thus has a rect that doesn't fit the button.
@@ -489,7 +489,7 @@ void QComboView::mousePressEvent( TQMouseEvent *e )
if ( arrowRect.contains( e->pos() ) ) {
d->arrowPressed = TRUE;
d->arrowDown = TRUE;
- tqrepaint( FALSE );
+ repaint( FALSE );
}
TQTimer::singleShot( 200, this, TQT_SLOT(internalClickTimeout()));
d->shortClick = TRUE;
@@ -700,12 +700,12 @@ static int listHeight( TQListView *l, int /*sl*/ )
prefH = ch * l->firstChild()->height();
}
else
- prefH = l->tqsizeHint().height();
+ prefH = l->sizeHint().height();
if (l->header()->isVisible())
- prefH += l->header()->tqsizeHint().height();
+ prefH += l->header()->sizeHint().height();
-// return prefH < l->tqsizeHint().height() ? prefH : l->tqsizeHint().height();
+// return prefH < l->sizeHint().height() ? prefH : l->sizeHint().height();
return prefH+2;
}
@@ -727,7 +727,7 @@ void QComboView::popup()
lb->installEventFilter( this );
lb->viewport()->installEventFilter( this );
d->mouseWasInsidePopup = FALSE;
-// int w = lb->variableWidth() ? lb->tqsizeHint().width() : width();
+// int w = lb->variableWidth() ? lb->sizeHint().width() : width();
int w = width();
int h = listHeight( lb, d->sizeLimit );
TQRect screen = TQApplication::desktop()->availableGeometry( const_cast<QComboView*>(this) );
@@ -790,7 +790,7 @@ void QComboView::updateMask()
{
TQPainter p( &bm, this );
- tqstyle().tqdrawComplexControlMask(TQStyle::CC_ComboBox, &p, this, rect());
+ tqstyle().drawComplexControlMask(TQStyle::CC_ComboBox, &p, this, rect());
}
setMask( bm );
@@ -808,7 +808,7 @@ void QComboView::popDownListView()
d->listView()->setCurrentItem( d->current );
if ( d->arrowDown ) {
d->arrowDown = FALSE;
- tqrepaint( FALSE );
+ repaint( FALSE );
}
d->poppedUp = FALSE;
}
@@ -904,21 +904,21 @@ bool QComboView::eventFilter( TQObject *object, TQEvent *event )
TQRect arrowRect =
tqstyle().querySubControlMetrics( TQStyle::CC_ComboBox, this,
TQStyle::SC_ComboBoxArrow);
- arrowRect = TQStyle::tqvisualRect(arrowRect, this);
+ arrowRect = TQStyle::visualRect(arrowRect, this);
if ( arrowRect.contains( comboPos ) ) {
if ( !d->arrowDown ) {
d->arrowDown = TRUE;
- tqrepaint( FALSE );
+ repaint( FALSE );
}
} else {
if ( d->arrowDown ) {
d->arrowDown = FALSE;
- tqrepaint( FALSE );
+ repaint( FALSE );
}
}
}
} else if ((e->state() & ( Qt::RightButton | Qt::LeftButton | Qt::MidButton ) ) == 0 &&
- tqstyle().tqstyleHint(TQStyle::SH_ComboBox_ListMouseTracking, this)) {
+ tqstyle().styleHint(TQStyle::SH_ComboBox_ListMouseTracking, this)) {
// qWarning("event filter:: emu");
TQWidget *mouseW = TQApplication::widgetAt( e->globalPos(), TRUE );
// if ( mouseW == d->listView()->viewport() ) { //###
@@ -948,7 +948,7 @@ bool QComboView::eventFilter( TQObject *object, TQEvent *event )
d->arrowPressed = FALSE;
if ( d->arrowDown ) {
d->arrowDown = FALSE;
- tqrepaint( FALSE );
+ repaint( FALSE );
}
}
}
@@ -1333,7 +1333,7 @@ bool QComboView::autoCompletion() const
*/
void QComboView::styleChange( TQStyle& s )
{
- d->tqsizeHint = TQSize(); // tqinvalidate size hint...
+ d->sizeHint = TQSize(); // invalidate size hint...
if ( d->ed )
d->updateLinedGeometry();
TQWidget::styleChange( s );